/*=============================================================================
	Copyright (c) 1999-2004 pmG Worldwide, LLC.

	File:	messiah_base.h
	Author:	Lyle Milton
	Date:	01/01/03

		last modified: 05/09/03 - LM
			- added variable, grouop, armature, handle, & action
		last modified: 03/11/04 - LM
			- removed the FX_Point type to avoid future datatype collisions.
			Use FX_Vector in place of FX_Point.
		last modified: 04/24/04 - LM
			- removed the FX_Point2D type to avoid future datatype collisions.
			Use FX_VectorF2D in place of FX_Point2D.

=============================================================================*/


#ifndef	__MESSIAH_BASE
#define __MESSIAH_BASE

//Base types-------------------------------------------------------------------
typedef double			FXdouble;
typedef float			FXfloat;
typedef fx_64bit		FXint64;
typedef long			FXlong;
typedef int				FXint;
typedef short			FXshort;
typedef char			FXbyte;
typedef char			FXchar;
typedef char			FXbool;
typedef unsigned long	FXulong;
typedef unsigned int	FXuint;
typedef unsigned short	FXushort;
typedef unsigned char	FXubyte;
typedef unsigned char	FXuchar;
typedef void			FXvoid;
typedef double			FXmatrix[4][4];
typedef double			FXvecd[3];
typedef float			FXvecf[3];
typedef int				FXveci[3];
typedef double			FXvecd4[4];
typedef float			FXvecf4[4];
typedef int				FXveci4[4];
typedef double			FXchannels[32];
//`````````````````````````````````````````````````````````````````````````````


//messiah data types-----------------------------------------------------------
typedef	FXint			FXentity;	//Arbitrary messiah data type.  Used when any other type is valid
typedef FXint			FXobject;	//Universal Object.  Generally used to represent geometric objects or any other "Object based" ID
typedef FXint			FXtool;		//Tool.  Object based
typedef FXint			FXeffect;	//Effect. Object based
typedef FXint			FXshader;	//Shader. Object based
typedef FXint			FXcontrol;	//Control.  GUI control
typedef FXint			FXimage;	//Image
typedef FXint			FXcommand;	//Command
typedef FXint			FXmodule;	//Arbitrary Module type.  Used to represent your module
typedef FXint			FXvariable;	//Expression Variable
typedef FXint			FXgroup;	//Group
typedef FXint			FXarmature;	//Armature
typedef FXint			FXhandle;	//Armature Handle
typedef FXint			FXaction;	//Action "object".

#define FX_NULLID		((FXint)0)
//`````````````````````````````````````````````````````````````````````````````


//-----------------------------------------------------------------------------
#ifndef	__MESSIAH_HIDE_TYPES

	typedef struct FX_Point3Struct 
	{
	   FXdouble x, y, z;

	} FX_Vector;

	typedef struct FX_Point3StructF
	{
	   FXfloat x, y, z;

	} FX_VectorF;

	typedef struct FX_Point2DStructF 
	{
	   FXfloat x, y;

	} FX_VectorF2D;

	typedef struct FX_ColorStruct
	{
	   FXfloat r, g, b;

	} FX_Color;

	typedef struct FX_Color4Struct
	{
	   FXfloat r, g, b, a;

	} FX_Color4;


	//,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
	//These types are to be used as the return in scan function definitions.
	//
	//	EX:
	//		FXintf MyScanFunc(...)
	//		{
	//			FXint i=0;
	//				.
	//				.
	//				.
	//			return i;
	//		}
	//
	//Alternatively, you can use the provided scanfunc macros which already use
	//these function return type defines
	//
	//`````````````````````````````````````````````````````````````````````````````
	#ifdef __cplusplus
		#define FX_CTYPE(t)	extern "C" t
	#else
		#define FX_CTYPE(t)	t
	#endif

	#define FXdoublef	FX_CTYPE(FXdouble)
	#define FXfloatf	FX_CTYPE(FXfloat)
	#define FXint64f	FX_CTYPE(FXint64)
	#define FXlongf		FX_CTYPE(FXlong)
	#define FXintf		FX_CTYPE(FXint)
	#define FXshortf	FX_CTYPE(FXshort)
	#define FXbytef		FX_CTYPE(FXbyte)
	#define FXcharf		FX_CTYPE(FXchar)
	#define FXboolf		FX_CTYPE(FXbool)
	#define FXulongf	FX_CTYPE(FXulong)
	#define FXuintf		FX_CTYPE(FXuint)
	#define FXushortf	FX_CTYPE(FXushort)
	#define FXubytef	FX_CTYPE(FXubyte)
	#define FXucharf	FX_CTYPE(FXuchar)
	#define FXvoidf		FX_CTYPE(FXvoid)


#endif	//__MESSIAH_HIDE_TYPES
//`````````````````````````````````````````````````````````````````````````````



#endif	//__MESSIAH_BASE
